@@ -17,6 +17,7 @@
 # author Salvo "LtWorf" Tomaselli <tiposchi@tiscali.it>
 
 
+import datetime
 from enum import Enum
 from typing import Dict, List, NamedTuple, Optional, Set, Tuple, Union
 import unittest
@@ -63,6 +64,11 @@ class TestBasicDump(unittest.TestCase):
         dumper = datadumper.Dumper()
         assert dumper.dump({EnumA.B: 'ciao'}) == {'2': 'ciao'}
 
+    def test_dump_set(self):
+        dumper = datadumper.Dumper()
+        assert dumper.dump(set(range(3))) == [0, 1, 2]
+        assert dumper.dump(frozenset(range(3))) == [0, 1, 2]
+
     def test_dump_enums(self):
         dumper = datadumper.Dumper()
         assert dumper.dump(EnumA.A) == 1
@@ -89,6 +95,12 @@ class TestBasicDump(unittest.TestCase):
             assert dumper.dump(None) == None
             assert dumper.dump(True) == True
 
+    def test_datetime(self):
+        dumper = datadumper.Dumper()
+        assert dumper.dump(datetime.date(2011, 12, 12)) == [2011, 12, 12]
+        assert dumper.dump(datetime.time(15, 41)) == [15, 41, 0, 0]
+        assert dumper.dump(datetime.datetime(2019, 5, 31, 12, 44, 22)) == [2019, 5, 31, 12, 44, 22, 0]
+
 
 class TestHandlersDumper(unittest.TestCase):
 
