@@ -42,7 +42,7 @@ class AnnotationType(Enum):
 
 Annotation = NamedTuple('Annotation', [
     ('annotation_type', AnnotationType),
-    ('value', Any),  # Actually Union[str, int, Type], but python 3.5.2 is idiotic
+    ('value', Union[str, int, Type]),
 ])
 
 
@@ -83,7 +83,7 @@ class TypedloadException(Exception):
             description: str,
             trace: Optional[List[TraceItem]] = None,
             value=None,
-            type_: Optional[Any] = None,  # Any should be Type, but that raises an exception in python 3.5.2
+            type_: Optional[Type] = None,
             exceptions: Optional[List[Exception]] = None) -> None:
         super().__init__(description)
         self.trace = trace if trace else []
@@ -109,7 +109,7 @@ class TypedloadException(Exception):
             e += 'Type: %s ' % i.type_
             if i.annotation:
                 e += 'Annotation: (%s %s) ' % (i.annotation[0], i.annotation[1])
-                path.append(str(i.annotation[1]) if type(i.annotation[1]) != int else '[%d]' % i.annotation[1])
+                path.append('[%d]' % i.annotation[1] if isinstance(i.annotation[1], int) else str(i.annotation[1]))
             else:
                 path.append(str(None))
             e += 'Value: %s\n' % compress_value(i.value)
