@@ -50,6 +50,7 @@ __all__ = [
     'is_set',
     'is_tuple',
     'is_union',
+    'is_typeddict',
     'uniontypes',
     'literalvalues',
     'NONETYPE',
@@ -67,9 +68,10 @@ except ImportError:
 
 try:
     # Since 3.8
-    from typing import Literal  # type: ignore
+    from typing import Literal, _TypedDictMeta  # type: ignore
 except ImportError:
     Literal = None
+    _TypedDictMeta = None
 
 def _issubclass(t1, t2) -> bool:
     """
@@ -83,6 +85,7 @@ def _issubclass(t1, t2) -> bool:
 
 HAS_TUPLEARGS = hasattr(Tuple[int, int], '__args__')
 NONETYPE = type(None)  # type: Type[Any]
+HAS_UNIONSUBCLASS = False
 
 
 def is_tuple(type_: Type[Any]) -> bool:
@@ -102,25 +105,13 @@ def is_tuple(type_: Type[Any]) -> bool:
         return _issubclass(type_, Tuple) and _issubclass(type_, tuple) == False
 
 
-# This is a workaround for an incompatibility between 3.5.2 and previous, and 3.5.3 and later
-try:
-    issubclass(Union[int,str], Union)  # type: ignore
-    HAS_UNIONSUBCLASS = True
-except:
-    HAS_UNIONSUBCLASS = False
-
-
 def is_union(type_: Type[Any]) -> bool:
     '''
     Union[A, B]
     Union
     Optional[A]
     '''
-    if HAS_UNIONSUBCLASS:
-        # Old python
-        return _issubclass(type_, Union)
-    else:
-        return getattr(type_, '__origin__', None) == Union
+    return getattr(type_, '__origin__', None) == Union
 
 
 def is_nonetype(type_: Type[Any]) -> bool:
@@ -177,7 +168,7 @@ def is_namedtuple(type_: Type[Any]) -> bool:
     '''
     Generated with typing.NamedTuple
     '''
-    return _issubclass(type_, tuple) and hasattr(type_, '_field_types') and hasattr(type_, '_fields')
+    return _issubclass(type_, tuple) and hasattr(type_, '__annotations__') and hasattr(type_, '_fields')
 
 
 def is_dataclass(type_: Type[Any]) -> bool:
@@ -239,3 +230,12 @@ def is_literal(type_: Type[Any]) -> bool:
     Check if the type is a typing.Literal
     '''
     return getattr(type_, '__origin__', None) == Literal and Literal != None
+
+
+def is_typeddict(type_: Type[Any]) -> bool:
+    '''
+    Check if it is a typing.TypedDict
+    '''
+    if _TypedDictMeta:
+        return isinstance(type_, _TypedDictMeta)
+    return False
